<?php
/*
Plugin Name:    EuropaFM News
Plugin URI:     https://developer.wordpress.org/plugins/efm-news/
Description:    Display news from EuropaFM.ro on your website.
Version:        0.6.1
Author:         EuropaFM
Author URI:     https://www.europafm.ro/
License:        MIT
License URI:    https://opensource.org/licenses/MIT
Text Domain:    efm-news
Programmer:     Octavian Iosif @ Nonsintetic Proiect
Programmer URI: www.nonsintetic.ro | www.nonsintetic.com
*/

//prevent direct access
defined( 'ABSPATH' ) or die();
define("EFM_NEWS_PLUGIN_URL",plugin_dir_url(__FILE__));
//include extra files
include('include/plugin-settings.php');
include('include/plugin-functions.php');
include('include/efm-news-widget.php');

//internationalization
load_plugin_textdomain('efm-news', false,  EFM_NEWS_PLUGIN_PATH. '/languages');

//Shortcode [europafm-news]
add_shortcode("europafm-news","efm_news_shortcode");
function efm_news_shortcode($attributes){
    return efm_news_render($attributes);
}

//Visual Composer Integration
add_action( 'vc_before_init', 'efm_news_vc_integration' );
function efm_news_vc_integration() {
    if(is_admin() && function_exists('vc_map')) {
        $efm_news_sources = efm_news_get_sources();
        $sources = array();
        foreach($efm_news_sources as $source) {
            $sources[$source['title']] = $source['url'];
        }
        vc_map(array(
            "name" => __( 'EuropaFM News', 'efm-news' ),
            "base" => "europafm-news",
            "category" => "Content",
            "params" => array(
                array(
                    "type" => "textfield",
                    "class" => "",
                    "heading" => __( 'Title:', 'efm-news' ),
                    "param_name" => "title",
                    "value" => "",
                ),
                array(
                    "type" => "dropdown",
                    "heading" => __( 'News Source:', 'efm-news' ),
                    "class" => "",
                    "param_name" => "source",
                    "value" => $sources
                ),
                array(
                    "type" => "textfield",
                    "class" => "",
                    "heading" => __( 'Number of posts:', 'efm-news' ),
                    "param_name" => "limit",
                    "value" => "5",
                ),
                array(
                    "type" => "dropdown",
                    "heading" => "Style",
                    "class" => "",
                    "param_name" => "style",
                    "value" => array(
                        __('Red Background (default)','efm-news') => 'red',
                        __('Minimalist','efm-news') => 'default'
                    )
                ),
                array(
                    "type" => "dropdown",
                    "heading" => __( 'Title container:', 'efm-news' ),
                    "class" => "",
                    "param_name" => "title-container",
                    "value" => array(
                        'DIV' => 'div',
                        'H1' => 'h1',
                        'H2' => 'h2',
                        'H3' => 'h3',
                        'H4' => 'h4',
                        'H5' => 'h5',
                        'P' => 'p'
                    )
                ),
                array(
                    "type" => "checkbox",
                    "class" => "",
                    "heading" => __( 'Hide images', 'efm-news' ),
                    "param_name" => "hide-images",
                    "value" => "1",
                ),
                array(
                    "type" => "checkbox",
                    "class" => "",
                    "heading" => __( 'Hide excerpt', 'efm-news' ),
                    "param_name" => "hide-excerpt",
                    "value" => "1",
                ),
                array(
                    "type" => "checkbox",
                    "class" => "",
                    "heading" => __( 'Hide credits', 'efm-news' ),
                    "param_name" => "hide-credits",
                    "value" => "1",
                ),
                array(
                    "type" => "checkbox",
                    "class" => "",
                    "heading" => __( 'Use built-in CSS styles', 'efm-news' ),
                    "param_name" => "use-css",
                    "value" => "1",
                    "std" => "true"
                ),
                array(
                    "type" => "textfield",
                    "class" => "",
                    "heading" => __( 'Font size (pixels):', 'efm-news' ),
                    "param_name" => "font-size",
                    "value" => "17",
                ),
                array(
                    "type" => "textfield",
                    "class" => "",
                    "heading" => __( 'Excerpt length:', 'efm-news' ),
                    "param_name" => "excerpt-length",
                    "value" => "230",
                ),
            )
        ));
    }
}