<?php
/*
 * Widget using the default WordPress API
 */
/* Register the widget with WP */
function efm_news_widget_register() {
    register_widget( 'EFM_News_Widget' );
}
add_action( 'widgets_init', 'efm_news_widget_register' );

/* Widget Class */
class EFM_News_Widget extends WP_Widget {
    function __construct() {
        parent::__construct(
            'efm_news_widget', // Base ID
            esc_html__( 'EuropaFM News', 'efm-news' ), // Name
            array( 'description' => esc_html__( 'Displays a news feed from EuropaFM.ro', 'efm-news' ), ) // Args
        );
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
    */
    public function widget( $args, $instance ) {
        echo efm_news_render($instance);
    }

    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     * @return array $instance New instance
     */
    public function form( $instance ) {
        $title = !empty( $instance['title'] ) ? $instance['title'] : "Știrile care contează";
        $title_container = !empty( $instance['title-container'] ) ? $instance['title-container'] : "h2";
        $source = !empty( $instance['source'] ) ? $instance['source'] : "stiri";
        $limit = !empty( $instance['limit'] ) ? $instance['limit'] : 5;
        $hide_excerpt = !empty( $instance['hide-excerpt'] ) ? $instance['hide-excerpt'] : 0;
        $hide_credits = !empty( $instance['hide-credits'] ) ? $instance['hide-credits'] : 0;
        $hide_images = !empty( $instance['hide-images'] ) ? $instance['hide-images'] : 0;
        $use_css = !empty( $instance['use-css'] ) ? $instance['use-css'] : 0;
        $style = !empty( $instance['style'] ) ? $instance['style'] : 'red';
        $font_size = !empty( $instance['font-size'] ) ? $instance['font-size'] : 16;
        $excerpt_length = !empty( $instance['excerpt-length'] ) ? $instance['excerpt-length'] : 230;
        ?>
        <img src="<?php echo EFM_NEWS_PLUGIN_URL ?>/res/efm-logo.png" width="80" height="38" style="margin-top: 10px" />
        <p style="background-color:#f1f1f1;padding: 5px;margin-bottom: 10px;"><strong><?php _e('Source Settings','efm-news') ?></strong></p>
        <p style="margin-top: 0">
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_attr_e( 'Title:', 'efm-news' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'source' ) ); ?>"><?php esc_attr_e( 'News Source:', 'efm-news' ); ?></label>
            <select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'source' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'source' ) ); ?>">
                <?php
                $news_sources = efm_news_get_sources();
                foreach($news_sources as $key=>$value) {
                    echo '<option value="'.$key.'" '.($key == $source?'selected':'').'>'.$value['title'].'</option>';
                }
                ?>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'limit' ) ); ?>"><?php esc_attr_e( 'Number of posts:', 'efm-news' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'limit' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'limit' ) ); ?>" type="number" min="1" max="10" step="1" value="<?php echo esc_attr( $limit ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>"><?php esc_attr_e( 'Widget style:', 'efm-news' ); ?></label>
            <select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'style' ) ); ?>">
                <option value="red" <?php echo ($style == 'red'?'selected':'') ?>><?php _e('Red Background (default)','efm-news'); ?></option>
                <option value="default" <?php echo ($style == 'default'?'selected':'') ?>><?php _e('Minimalist','efm-news'); ?></option>
            </select>
        </p>
        <p style="background-color:#f1f1f1;padding: 5px;margin-bottom: 10px;"><strong><?php _e("Display Settings","efm-news") ?></strong></p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title-container' ) ); ?>"><?php esc_attr_e( 'Title container:', 'efm-news' ); ?></label>
            <select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title-container' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title-container' ) ); ?>">
                <option value="div" <?php echo ($title_container == 'div'?'selected':'') ?>>DIV</option>
                <option value="h2" <?php echo ($title_container == 'h2'?'selected':'') ?>>H2</option>
                <option value="h3" <?php echo ($title_container == 'h3'?'selected':'') ?>>H3</option>
                <option value="h4" <?php echo ($title_container == 'h4'?'selected':'') ?>>H4</option>
                <option value="h5" <?php echo ($title_container == 'h5'?'selected':'') ?>>H5</option>
                <option value="p" <?php echo ($title_container == 'p'?'selected':'') ?>>P</option>
            </select>
        </p>
        <p>
            <input type="checkbox" value="1" id="<?php echo esc_attr( $this->get_field_id( 'hide-images' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'hide-images' ) ); ?>" <?php echo ($hide_images== '1'?'checked':'') ?> />
            <label for="<?php echo esc_attr( $this->get_field_id( 'hide-images' ) ); ?>"><?php esc_attr_e( 'Hide images', 'efm-news' ); ?></label>
        </p>
        <p>
            <input type="checkbox" value="1" id="<?php echo esc_attr( $this->get_field_id( 'hide-excerpt' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'hide-excerpt' ) );?>" <?php echo ($hide_excerpt == 1?' checked':'') ?> />
            <label for="<?php echo esc_attr( $this->get_field_id( 'hide-excerpt' ) ); ?>"><?php esc_attr_e( 'Hide excerpt', 'efm-news' ); ?></label>
        </p>
        <p>
            <input type="checkbox" value="1" id="<?php echo esc_attr( $this->get_field_id( 'hide-credits' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'hide-credits' ) ); ?>" <?php echo ($hide_credits == 1?' checked':'') ?> />
            <label for="<?php echo esc_attr( $this->get_field_id( 'hide-credits' ) ); ?>"><?php esc_attr_e( 'Hide credits', 'efm-news' ); ?></label>
        </p>
        <p>
            <input type="checkbox" value="1" id="<?php echo esc_attr( $this->get_field_id( 'use-css' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'use-css' ) ); ?>" <?php echo ($use_css == 1?' checked':'') ?> />
            <label for="<?php echo esc_attr( $this->get_field_id( 'use-css' ) ); ?>"><?php esc_attr_e( 'Use built-in CSS styles', 'efm-news' ); ?></label>
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'font-size' ) ); ?>"><?php esc_attr_e( 'Font size (pixels):', 'efm-news' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'font-size' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'font-size' ) ); ?>" type="number" min="1" step="1" value="<?php echo esc_attr( $font_size ); ?>">
            <small style="color:#d1d1d1"><?php _e('This is the size of the excerpt text font. All other font sizes are derived from it automatically.','efm-news') ?></small>
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'excerpt-length' ) ); ?>"><?php esc_attr_e( 'Excerpt length:', 'efm-news' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'excerpt-length' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'excerpt-length' ) ); ?>" type="number" min="1" max="250" step="1" value="<?php echo esc_attr( $excerpt_length ); ?>">
            <small style="color:#d1d1d1"><?php _e('This is the length of the excerpt (number of letters).','efm-news'); ?></small>
        </p>
        <?php
    }

    /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param array $new_instance Values just sent to be saved.
     * @param array $old_instance Previously saved values from database.
     *
     * @return array Updated safe values to be saved.
     */
    public function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['title-container'] = ( ! empty( $new_instance['title-container'] ) ) ? strip_tags( $new_instance['title-container'] ) : '';
        $instance['source'] = ( ! empty( $new_instance['source'] ) ) ? strip_tags( $new_instance['source'] ) : '';
        $instance['limit'] = ( ! empty( $new_instance['limit'] ) ) ? strip_tags( $new_instance['limit'] ) : '';
        $instance['hide-images'] = ( ! empty( $new_instance['hide-images'] ) ) ? strip_tags( $new_instance['hide-images'] ) : '';
        $instance['hide-excerpt'] = ( ! empty( $new_instance['hide-excerpt'] ) ) ? strip_tags( $new_instance['hide-excerpt'] ) : '';
        $instance['hide-credits'] = ( ! empty( $new_instance['hide-credits'] ) ) ? strip_tags( $new_instance['hide-credits'] ) : '';
        $instance['style'] = ( ! empty( $new_instance['style'] ) ) ? strip_tags( $new_instance['style'] ) : '';
        $instance['font-size'] = ( ! empty( $new_instance['font-size'] ) ) ? strip_tags( $new_instance['font-size'] ) : '';
        $instance['excerpt-length'] = ( ! empty( $new_instance['excerpt-length'] ) ) ? strip_tags( $new_instance['excerpt-length'] ) : '';

        return $instance;
    }

} // class Foo_Widget